You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@struts.apache.org by mr...@apache.org on 2006/07/02 01:37:11 UTC

svn commit: r418521 [6/9] - in /struts/struts2/trunk/core: ./ src/main/java/org/apache/struts/action2/ src/main/java/org/apache/struts2/ src/main/java/org/apache/struts2/components/ src/main/java/org/apache/struts2/components/table/ src/main/java/org/a...

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ParamTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ParamTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ParamTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ParamTag.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp;
+package org.apache.struts2.views.jsp;
 
-import org.apache.struts.action2.components.Component;
-import org.apache.struts.action2.components.Param;
+import org.apache.struts2.components.Component;
+import org.apache.struts2.components.Param;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/PropertyTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/PropertyTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/PropertyTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/PropertyTag.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp;
+package org.apache.struts2.views.jsp;
 
-import org.apache.struts.action2.components.Component;
-import org.apache.struts.action2.components.Property;
+import org.apache.struts2.components.Component;
+import org.apache.struts2.components.Property;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/PushTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/PushTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/PushTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/PushTag.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp;
+package org.apache.struts2.views.jsp;
 
-import org.apache.struts.action2.components.Component;
-import org.apache.struts.action2.components.Push;
+import org.apache.struts2.components.Component;
+import org.apache.struts2.components.Push;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/SetTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/SetTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/SetTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/SetTag.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp;
+package org.apache.struts2.views.jsp;
 
-import org.apache.struts.action2.components.Component;
-import org.apache.struts.action2.components.Set;
+import org.apache.struts2.components.Component;
+import org.apache.struts2.components.Set;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/StrutsBodyTagSupport.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/StrutsBodyTagSupport.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/StrutsBodyTagSupport.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/StrutsBodyTagSupport.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp;
+package org.apache.struts2.views.jsp;
 
-import org.apache.struts.action2.util.FastByteArrayOutputStream;
-import org.apache.struts.action2.views.util.ContextUtil;
+import org.apache.struts2.util.FastByteArrayOutputStream;
+import org.apache.struts2.views.util.ContextUtil;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.jsp.tagext.BodyTagSupport;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/TagUtils.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/TagUtils.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/TagUtils.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/TagUtils.java Sat Jul  1 16:36:50 2006
@@ -15,18 +15,18 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp;
+package org.apache.struts2.views.jsp;
 
-import org.apache.struts.action2.RequestUtils;
-import org.apache.struts.action2.ServletActionContext;
-import org.apache.struts.action2.dispatcher.ApplicationMap;
-import org.apache.struts.action2.dispatcher.DispatcherUtils;
-import org.apache.struts.action2.dispatcher.RequestMap;
-import org.apache.struts.action2.dispatcher.SessionMap;
-import org.apache.struts.action2.dispatcher.mapper.ActionMapper;
-import org.apache.struts.action2.dispatcher.mapper.ActionMapperFactory;
-import org.apache.struts.action2.dispatcher.mapper.ActionMapping;
-import org.apache.struts.action2.util.AttributeMap;
+import org.apache.struts2.RequestUtils;
+import org.apache.struts2.ServletActionContext;
+import org.apache.struts2.dispatcher.ApplicationMap;
+import org.apache.struts2.dispatcher.DispatcherUtils;
+import org.apache.struts2.dispatcher.RequestMap;
+import org.apache.struts2.dispatcher.SessionMap;
+import org.apache.struts2.dispatcher.mapper.ActionMapper;
+import org.apache.struts2.dispatcher.mapper.ActionMapperFactory;
+import org.apache.struts2.dispatcher.mapper.ActionMapping;
+import org.apache.struts2.util.AttributeMap;
 import com.opensymphony.xwork.ActionContext;
 import com.opensymphony.xwork.ActionInvocation;
 import com.opensymphony.xwork.util.OgnlValueStack;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/TextTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/TextTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/TextTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/TextTag.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp;
+package org.apache.struts2.views.jsp;
 
-import org.apache.struts.action2.components.Component;
-import org.apache.struts.action2.components.Text;
+import org.apache.struts2.components.Component;
+import org.apache.struts2.components.Text;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/URLTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/URLTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/URLTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/URLTag.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp;
+package org.apache.struts2.views.jsp;
 
-import org.apache.struts.action2.components.Component;
-import org.apache.struts.action2.components.URL;
+import org.apache.struts2.components.Component;
+import org.apache.struts2.components.URL;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/iterator/AppendIteratorTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/iterator/AppendIteratorTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/iterator/AppendIteratorTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/iterator/AppendIteratorTag.java Sat Jul  1 16:36:50 2006
@@ -15,11 +15,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.iterator;
+package org.apache.struts2.views.jsp.iterator;
 
-import org.apache.struts.action2.components.AppendIterator;
-import org.apache.struts.action2.components.Component;
-import org.apache.struts.action2.views.jsp.ComponentTagSupport;
+import org.apache.struts2.components.AppendIterator;
+import org.apache.struts2.components.Component;
+import org.apache.struts2.views.jsp.ComponentTagSupport;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/iterator/IteratorGeneratorTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/iterator/IteratorGeneratorTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/iterator/IteratorGeneratorTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/iterator/IteratorGeneratorTag.java Sat Jul  1 16:36:50 2006
@@ -15,11 +15,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.iterator;
+package org.apache.struts2.views.jsp.iterator;
 
-import org.apache.struts.action2.util.IteratorGenerator;
-import org.apache.struts.action2.util.IteratorGenerator.Converter;
-import org.apache.struts.action2.views.jsp.StrutsBodyTagSupport;
+import org.apache.struts2.util.IteratorGenerator;
+import org.apache.struts2.util.IteratorGenerator.Converter;
+import org.apache.struts2.views.jsp.StrutsBodyTagSupport;
 
 import javax.servlet.jsp.JspException;
 
@@ -118,7 +118,7 @@
  * this converter, it simply add "converter-" to each entries.
  * <!-- END SNIPPET: example -->
  *
- * @see org.apache.struts.action2.util.IteratorGenerator
+ * @see org.apache.struts2.util.IteratorGenerator
  *
  * @ww.tag name="generator" tld-body-content="JSP"
  * description="Generate an iterator for a iterable source."
@@ -163,7 +163,7 @@
     }
 
     /**
-     * @ww.tagattribute required="false" type="org.apache.struts.action2.util.IteratorGenerator.Converter"
+     * @ww.tagattribute required="false" type="org.apache.struts2.util.IteratorGenerator.Converter"
      * description="the converter to convert the String entry parsed from <i>val</i> into an object"
      */
     public void setConverter(String aConverter) {

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/iterator/MergeIteratorTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/iterator/MergeIteratorTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/iterator/MergeIteratorTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/iterator/MergeIteratorTag.java Sat Jul  1 16:36:50 2006
@@ -15,11 +15,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.iterator;
+package org.apache.struts2.views.jsp.iterator;
 
-import org.apache.struts.action2.components.Component;
-import org.apache.struts.action2.components.MergeIterator;
-import org.apache.struts.action2.views.jsp.ComponentTagSupport;
+import org.apache.struts2.components.Component;
+import org.apache.struts2.components.MergeIterator;
+import org.apache.struts2.views.jsp.ComponentTagSupport;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;
@@ -31,7 +31,7 @@
  * into one iterator.
  *
  * @see MergeIterator
- * @see org.apache.struts.action2.util.MergeIteratorFilter
+ * @see org.apache.struts2.util.MergeIteratorFilter
  */
 public class MergeIteratorTag extends ComponentTagSupport {
 

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/iterator/SortIteratorTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/iterator/SortIteratorTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/iterator/SortIteratorTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/iterator/SortIteratorTag.java Sat Jul  1 16:36:50 2006
@@ -15,11 +15,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.iterator;
+package org.apache.struts2.views.jsp.iterator;
 
-import org.apache.struts.action2.util.MakeIterator;
-import org.apache.struts.action2.util.SortIteratorFilter;
-import org.apache.struts.action2.views.jsp.StrutsBodyTagSupport;
+import org.apache.struts2.util.MakeIterator;
+import org.apache.struts2.util.SortIteratorFilter;
+import org.apache.struts2.views.jsp.StrutsBodyTagSupport;
 
 import javax.servlet.jsp.JspException;
 
@@ -76,7 +76,7 @@
  * </pre>
  *
  *
- * @see org.apache.struts.action2.util.SortIteratorFilter
+ * @see org.apache.struts2.util.SortIteratorFilter
  *
  * @ww.tag name="sort" tld-body-content="JSP"
  * description="Sort a List using a Comparator both passed in as the tag attribute."

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/iterator/SubsetIteratorTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/iterator/SubsetIteratorTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/AbstractClosingTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/AbstractClosingTag.java Sat Jul  1 16:36:50 2006
@@ -15,9 +15,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.ui;
+package org.apache.struts2.views.jsp.ui;
 
-import org.apache.struts.action2.components.ClosingUIBean;
+import org.apache.struts2.components.ClosingUIBean;
 
 /**
  */

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/AbstractDoubleListTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/AbstractDoubleListTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/AbstractDoubleListTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/AbstractDoubleListTag.java Sat Jul  1 16:36:50 2006
@@ -15,9 +15,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.ui;
+package org.apache.struts2.views.jsp.ui;
 
-import org.apache.struts.action2.components.DoubleListUIBean;
+import org.apache.struts2.components.DoubleListUIBean;
 
 
 /**

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/AbstractListTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/AbstractListTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/AbstractListTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/AbstractListTag.java Sat Jul  1 16:36:50 2006
@@ -15,9 +15,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.ui;
+package org.apache.struts2.views.jsp.ui;
 
-import org.apache.struts.action2.components.ListUIBean;
+import org.apache.struts2.components.ListUIBean;
 
 /**
  */

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/AbstractRequiredListTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/AbstractRequiredListTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/AbstractRequiredListTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/AbstractRequiredListTag.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.ui;
+package org.apache.struts2.views.jsp.ui;
 
 
-import org.apache.struts.action2.components.ListUIBean;
+import org.apache.struts2.components.ListUIBean;
 
 /**
  */

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/AbstractRichtexteditorResult.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/AbstractRichtexteditorResult.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/AbstractUITag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/AbstractUITag.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.ui;
+package org.apache.struts2.views.jsp.ui;
 
-import org.apache.struts.action2.components.UIBean;
-import org.apache.struts.action2.views.jsp.ComponentTagSupport;
+import org.apache.struts2.components.UIBean;
+import org.apache.struts2.views.jsp.ComponentTagSupport;
 
 
 /**

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/ActionErrorTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/ActionErrorTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/ActionErrorTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/ActionErrorTag.java Sat Jul  1 16:36:50 2006
@@ -15,13 +15,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.ui;
+package org.apache.struts2.views.jsp.ui;
 
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
-import org.apache.struts.action2.components.ActionError;
-import org.apache.struts.action2.components.Component;
+import org.apache.struts2.components.ActionError;
+import org.apache.struts2.components.Component;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 /**

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/ActionMessageTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/ActionMessageTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/ActionMessageTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/ActionMessageTag.java Sat Jul  1 16:36:50 2006
@@ -15,13 +15,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.ui;
+package org.apache.struts2.views.jsp.ui;
 
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
-import org.apache.struts.action2.components.ActionMessage;
-import org.apache.struts.action2.components.Component;
+import org.apache.struts2.components.ActionMessage;
+import org.apache.struts2.components.Component;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 /**

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/AnchorTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/AnchorTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/AnchorTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/AnchorTag.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.ui;
+package org.apache.struts2.views.jsp.ui;
 
-import org.apache.struts.action2.components.Component;
-import org.apache.struts.action2.components.Anchor;
+import org.apache.struts2.components.Component;
+import org.apache.struts2.components.Anchor;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/CheckboxListTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/CheckboxListTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/CheckboxListTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/CheckboxListTag.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.ui;
+package org.apache.struts2.views.jsp.ui;
 
-import org.apache.struts.action2.components.CheckboxList;
-import org.apache.struts.action2.components.Component;
+import org.apache.struts2.components.CheckboxList;
+import org.apache.struts2.components.Component;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/CheckboxTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/CheckboxTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/CheckboxTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/CheckboxTag.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.ui;
+package org.apache.struts2.views.jsp.ui;
 
-import org.apache.struts.action2.components.Checkbox;
-import org.apache.struts.action2.components.Component;
+import org.apache.struts2.components.Checkbox;
+import org.apache.struts2.components.Component;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/ComboBoxTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/ComboBoxTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/ComboBoxTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/ComboBoxTag.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.ui;
+package org.apache.struts2.views.jsp.ui;
 
-import org.apache.struts.action2.components.ComboBox;
-import org.apache.struts.action2.components.Component;
+import org.apache.struts2.components.ComboBox;
+import org.apache.struts2.components.Component;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/ComponentTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/ComponentTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/ComponentTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/ComponentTag.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.ui;
+package org.apache.struts2.views.jsp.ui;
 
-import org.apache.struts.action2.components.Component;
-import org.apache.struts.action2.components.GenericUIBean;
+import org.apache.struts2.components.Component;
+import org.apache.struts2.components.GenericUIBean;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/DatePickerTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/DatePickerTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/DatePickerTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/DatePickerTag.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.ui;
+package org.apache.struts2.views.jsp.ui;
 
-import org.apache.struts.action2.components.Component;
-import org.apache.struts.action2.components.DatePicker;
+import org.apache.struts2.components.Component;
+import org.apache.struts2.components.DatePicker;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/DivTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/DivTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/DivTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/DivTag.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.ui;
+package org.apache.struts2.views.jsp.ui;
 
-import org.apache.struts.action2.components.Component;
-import org.apache.struts.action2.components.Div;
+import org.apache.struts2.components.Component;
+import org.apache.struts2.components.Div;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/DoubleSelectTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/DoubleSelectTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/DoubleSelectTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/DoubleSelectTag.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.ui;
+package org.apache.struts2.views.jsp.ui;
 
-import org.apache.struts.action2.components.Component;
-import org.apache.struts.action2.components.DoubleSelect;
+import org.apache.struts2.components.Component;
+import org.apache.struts2.components.DoubleSelect;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/FieldErrorTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/FieldErrorTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/FieldErrorTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/FieldErrorTag.java Sat Jul  1 16:36:50 2006
@@ -15,13 +15,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.ui;
+package org.apache.struts2.views.jsp.ui;
 
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
-import org.apache.struts.action2.components.Component;
-import org.apache.struts.action2.components.FieldError;
+import org.apache.struts2.components.Component;
+import org.apache.struts2.components.FieldError;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 /**

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/FileTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/FileTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/FileTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/FileTag.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.ui;
+package org.apache.struts2.views.jsp.ui;
 
-import org.apache.struts.action2.components.Component;
-import org.apache.struts.action2.components.File;
+import org.apache.struts2.components.Component;
+import org.apache.struts2.components.File;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/FormTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/FormTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/FormTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/FormTag.java Sat Jul  1 16:36:50 2006
@@ -15,13 +15,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.ui;
+package org.apache.struts2.views.jsp.ui;
 
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
-import org.apache.struts.action2.components.Component;
-import org.apache.struts.action2.components.Form;
+import org.apache.struts2.components.Component;
+import org.apache.struts2.components.Form;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/HeadTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/HeadTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/HeadTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/HeadTag.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.ui;
+package org.apache.struts2.views.jsp.ui;
 
-import org.apache.struts.action2.components.Component;
-import org.apache.struts.action2.components.Head;
+import org.apache.struts2.components.Component;
+import org.apache.struts2.components.Head;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/HiddenTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/HiddenTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/HiddenTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/HiddenTag.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.ui;
+package org.apache.struts2.views.jsp.ui;
 
-import org.apache.struts.action2.components.Component;
-import org.apache.struts.action2.components.Hidden;
+import org.apache.struts2.components.Component;
+import org.apache.struts2.components.Hidden;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/LabelTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/LabelTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/LabelTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/LabelTag.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.ui;
+package org.apache.struts2.views.jsp.ui;
 
-import org.apache.struts.action2.components.Component;
-import org.apache.struts.action2.components.Label;
+import org.apache.struts2.components.Component;
+import org.apache.struts2.components.Label;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/OgnlTool.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/OgnlTool.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/OgnlTool.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/OgnlTool.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.ui;
+package org.apache.struts2.views.jsp.ui;
 
 import com.opensymphony.xwork.util.OgnlUtil;
 import ognl.Ognl;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/OptionTransferSelectTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/OptionTransferSelectTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/OptionTransferSelectTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/OptionTransferSelectTag.java Sat Jul  1 16:36:50 2006
@@ -15,13 +15,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.ui;
+package org.apache.struts2.views.jsp.ui;
 
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
-import org.apache.struts.action2.components.Component;
-import org.apache.struts.action2.components.OptionTransferSelect;
+import org.apache.struts2.components.Component;
+import org.apache.struts2.components.OptionTransferSelect;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 /**

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/PanelTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/PanelTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/PanelTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/PanelTag.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.ui;
+package org.apache.struts2.views.jsp.ui;
 
-import org.apache.struts.action2.components.Component;
-import org.apache.struts.action2.components.Panel;
+import org.apache.struts2.components.Component;
+import org.apache.struts2.components.Panel;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/PasswordTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/PasswordTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/PasswordTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/PasswordTag.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.ui;
+package org.apache.struts2.views.jsp.ui;
 
-import org.apache.struts.action2.components.Component;
-import org.apache.struts.action2.components.Password;
+import org.apache.struts2.components.Component;
+import org.apache.struts2.components.Password;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/RadioTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/RadioTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/RadioTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/RadioTag.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.ui;
+package org.apache.struts2.views.jsp.ui;
 
-import org.apache.struts.action2.components.Component;
-import org.apache.struts.action2.components.Radio;
+import org.apache.struts2.components.Component;
+import org.apache.struts2.components.Radio;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/ResetTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/ResetTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/ResetTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/ResetTag.java Sat Jul  1 16:36:50 2006
@@ -15,17 +15,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.ui;
+package org.apache.struts2.views.jsp.ui;
 
-import org.apache.struts.action2.components.Component;
-import org.apache.struts.action2.components.Reset;
+import org.apache.struts2.components.Component;
+import org.apache.struts2.components.Reset;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
 /**
- * @see org.apache.struts.action2.components.Reset
+ * @see org.apache.struts2.components.Reset
  */
 public class ResetTag extends AbstractUITag {
 	

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/RichTextEditorTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/RichTextEditorTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/RichTextEditorTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/RichTextEditorTag.java Sat Jul  1 16:36:50 2006
@@ -15,13 +15,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.ui;
+package org.apache.struts2.views.jsp.ui;
 
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
-import org.apache.struts.action2.components.Component;
-import org.apache.struts.action2.components.RichTextEditor;
+import org.apache.struts2.components.Component;
+import org.apache.struts2.components.RichTextEditor;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 /**

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/SelectTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/SelectTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/SelectTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/SelectTag.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.ui;
+package org.apache.struts2.views.jsp.ui;
 
-import org.apache.struts.action2.components.Component;
-import org.apache.struts.action2.components.Select;
+import org.apache.struts2.components.Component;
+import org.apache.struts2.components.Select;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/SubmitTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/SubmitTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/SubmitTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/SubmitTag.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.ui;
+package org.apache.struts2.views.jsp.ui;
 
-import org.apache.struts.action2.components.Component;
-import org.apache.struts.action2.components.Submit;
+import org.apache.struts2.components.Component;
+import org.apache.struts2.components.Submit;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/TabbedPanelTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/TabbedPanelTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/TabbedPanelTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/TabbedPanelTag.java Sat Jul  1 16:36:50 2006
@@ -15,11 +15,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.ui;
+package org.apache.struts2.views.jsp.ui;
 
-import org.apache.struts.action2.components.Component;
-import org.apache.struts.action2.components.Panel;
-import org.apache.struts.action2.components.TabbedPanel;
+import org.apache.struts2.components.Component;
+import org.apache.struts2.components.Panel;
+import org.apache.struts2.components.TabbedPanel;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/TextFieldTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/TextFieldTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/TextFieldTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/TextFieldTag.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.ui;
+package org.apache.struts2.views.jsp.ui;
 
-import org.apache.struts.action2.components.Component;
-import org.apache.struts.action2.components.TextField;
+import org.apache.struts2.components.Component;
+import org.apache.struts2.components.TextField;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/TextareaTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/TextareaTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/TextareaTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/TextareaTag.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.ui;
+package org.apache.struts2.views.jsp.ui;
 
-import org.apache.struts.action2.components.Component;
-import org.apache.struts.action2.components.TextArea;
+import org.apache.struts2.components.Component;
+import org.apache.struts2.components.TextArea;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/TokenTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/TokenTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/TokenTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/TokenTag.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.ui;
+package org.apache.struts2.views.jsp.ui;
 
-import org.apache.struts.action2.components.Component;
-import org.apache.struts.action2.components.Token;
+import org.apache.struts2.components.Component;
+import org.apache.struts2.components.Token;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/TreeNodeTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/TreeNodeTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/TreeNodeTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/TreeNodeTag.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.ui;
+package org.apache.struts2.views.jsp.ui;
 
-import org.apache.struts.action2.components.Component;
-import org.apache.struts.action2.components.TreeNode;
+import org.apache.struts2.components.Component;
+import org.apache.struts2.components.TreeNode;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/TreeTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/TreeTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/TreeTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/TreeTag.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.ui;
+package org.apache.struts2.views.jsp.ui;
 
-import org.apache.struts.action2.components.Component;
-import org.apache.struts.action2.components.Tree;
+import org.apache.struts2.components.Component;
+import org.apache.struts2.components.Tree;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/UpDownSelectTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/UpDownSelectTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/UpDownSelectTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/UpDownSelectTag.java Sat Jul  1 16:36:50 2006
@@ -15,13 +15,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.ui;
+package org.apache.struts2.views.jsp.ui;
 
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
-import org.apache.struts.action2.components.Component;
-import org.apache.struts.action2.components.UpDownSelect;
+import org.apache.struts2.components.Component;
+import org.apache.struts2.components.UpDownSelect;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 /**

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/table/WebTableTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/table/WebTableTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/table/WebTableTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/table/WebTableTag.java Sat Jul  1 16:36:50 2006
@@ -15,11 +15,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.ui.table;
+package org.apache.struts2.views.jsp.ui.table;
 
-import org.apache.struts.action2.components.Component;
-import org.apache.struts.action2.components.table.WebTable;
-import org.apache.struts.action2.views.jsp.ui.ComponentTag;
+import org.apache.struts2.components.Component;
+import org.apache.struts2.components.table.WebTable;
+import org.apache.struts2.views.jsp.ui.ComponentTag;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/tiles/TilesResult.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/tiles/TilesResult.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/tiles/TilesResult.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/tiles/TilesResult.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.tiles;
+package org.apache.struts2.views.tiles;
 
-import org.apache.struts.action2.ServletActionContext;
-import org.apache.struts.action2.dispatcher.ServletDispatcherResult;
+import org.apache.struts2.ServletActionContext;
+import org.apache.struts2.dispatcher.ServletDispatcherResult;
 import com.opensymphony.xwork.ActionInvocation;
 import com.opensymphony.xwork.LocaleProvider;
 import org.apache.commons.logging.Log;
@@ -65,7 +65,7 @@
  * Making this result type the default for the current package.
  *
  * <result-types>
- *      <result-type name="tiles" class="org.apache.struts.action2.views.tiles.TilesResult" default="true" />
+ *      <result-type name="tiles" class="org.apache.struts2.views.tiles.TilesResult" default="true" />
  * </result-types>
  * <!-- END SNIPPET: packageconfig -->
  *

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/util/ContextUtil.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/util/ContextUtil.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/util/ContextUtil.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/util/ContextUtil.java Sat Jul  1 16:36:50 2006
@@ -15,15 +15,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.util;
+package org.apache.struts2.views.util;
 
 import com.opensymphony.xwork.util.OgnlValueStack;
 import com.opensymphony.xwork.ActionInvocation;
 import com.opensymphony.xwork.ActionContext;
-import org.apache.struts.action2.views.jsp.ui.OgnlTool;
-import org.apache.struts.action2.config.Configuration;
-import org.apache.struts.action2.util.StrutsUtil;
-import org.apache.struts.action2.StrutsConstants;
+import org.apache.struts2.views.jsp.ui.OgnlTool;
+import org.apache.struts2.config.Configuration;
+import org.apache.struts2.util.StrutsUtil;
+import org.apache.struts2.StrutsConstants;
 
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/util/ResourceUtil.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/util/ResourceUtil.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/util/ResourceUtil.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/util/ResourceUtil.java Sat Jul  1 16:36:50 2006
@@ -15,11 +15,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.util;
+package org.apache.struts2.views.util;
 
 import javax.servlet.http.HttpServletRequest;
 
-import org.apache.struts.action2.RequestUtils;
+import org.apache.struts2.RequestUtils;
 
 /**
  */

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/util/TextUtil.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/util/TextUtil.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/util/TextUtil.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/util/TextUtil.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.util;
+package org.apache.struts2.views.util;
 
 
 /**

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/util/UrlHelper.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/util/UrlHelper.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/util/UrlHelper.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/util/UrlHelper.java Sat Jul  1 16:36:50 2006
@@ -15,11 +15,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.util;
+package org.apache.struts2.views.util;
 
-import org.apache.struts.action2.ServletActionContext;
-import org.apache.struts.action2.StrutsConstants;
-import org.apache.struts.action2.config.Configuration;
+import org.apache.struts2.ServletActionContext;
+import org.apache.struts2.StrutsConstants;
+import org.apache.struts2.config.Configuration;
 import com.opensymphony.xwork.ActionContext;
 import com.opensymphony.xwork.util.OgnlValueStack;
 import com.opensymphony.xwork.util.TextParseUtil;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/StrutsResourceLoader.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/StrutsResourceLoader.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/StrutsResourceLoader.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/StrutsResourceLoader.java Sat Jul  1 16:36:50 2006
@@ -15,9 +15,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.velocity;
+package org.apache.struts2.views.velocity;
 
-import org.apache.struts.action2.util.ClassLoaderUtils;
+import org.apache.struts2.util.ClassLoaderUtils;
 import org.apache.velocity.exception.ResourceNotFoundException;
 import org.apache.velocity.runtime.resource.loader.ClasspathResourceLoader;
 

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/StrutsVelocityContext.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/StrutsVelocityContext.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/StrutsVelocityContext.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/StrutsVelocityContext.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.velocity;
+package org.apache.struts2.views.velocity;
 
 import com.opensymphony.xwork.util.OgnlValueStack;
 import org.apache.velocity.VelocityContext;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/StrutsVelocityServlet.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/StrutsVelocityServlet.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/components/AbstractDirective.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/components/AbstractDirective.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.velocity.components;
+package org.apache.struts2.views.velocity.components;
 
-import org.apache.struts.action2.ServletActionContext;
-import org.apache.struts.action2.components.Component;
+import org.apache.struts2.ServletActionContext;
+import org.apache.struts2.components.Component;
 import com.opensymphony.xwork.util.OgnlValueStack;
 import org.apache.velocity.context.InternalContextAdapter;
 import org.apache.velocity.exception.MethodInvocationException;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/components/ActionDirective.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/components/ActionDirective.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/components/ActionDirective.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/components/ActionDirective.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.velocity.components;
+package org.apache.struts2.views.velocity.components;
 
-import org.apache.struts.action2.components.ActionComponent;
-import org.apache.struts.action2.components.Component;
+import org.apache.struts2.components.ActionComponent;
+import org.apache.struts2.components.Component;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/components/ActionErrorDirective.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/components/ActionErrorDirective.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/components/ActionErrorDirective.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/components/ActionErrorDirective.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.velocity.components;
+package org.apache.struts2.views.velocity.components;
 
-import org.apache.struts.action2.components.Component;
-import org.apache.struts.action2.components.ActionError;
+import org.apache.struts2.components.Component;
+import org.apache.struts2.components.ActionError;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/components/ActionMessageDirective.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/components/ActionMessageDirective.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/components/ActionMessageDirective.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/components/ActionMessageDirective.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.velocity.components;
+package org.apache.struts2.views.velocity.components;
 
-import org.apache.struts.action2.components.Component;
-import org.apache.struts.action2.components.ActionMessage;
+import org.apache.struts2.components.Component;
+import org.apache.struts2.components.ActionMessage;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/components/AnchorDirective.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/components/AnchorDirective.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/components/AnchorDirective.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/components/AnchorDirective.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.velocity.components;
+package org.apache.struts2.views.velocity.components;
 
-import org.apache.struts.action2.components.Component;
-import org.apache.struts.action2.components.Anchor;
+import org.apache.struts2.components.Component;
+import org.apache.struts2.components.Anchor;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/components/BeanDirective.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/components/BeanDirective.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/components/BeanDirective.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/components/BeanDirective.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.velocity.components;
+package org.apache.struts2.views.velocity.components;
 
-import org.apache.struts.action2.components.Bean;
-import org.apache.struts.action2.components.Component;
+import org.apache.struts2.components.Bean;
+import org.apache.struts2.components.Component;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/components/CheckBoxDirective.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/components/CheckBoxDirective.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/components/CheckBoxDirective.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/components/CheckBoxDirective.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.velocity.components;
+package org.apache.struts2.views.velocity.components;
 
-import org.apache.struts.action2.components.Checkbox;
-import org.apache.struts.action2.components.Component;
+import org.apache.struts2.components.Checkbox;
+import org.apache.struts2.components.Component;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/components/CheckBoxListDirective.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/components/CheckBoxListDirective.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/components/CheckBoxListDirective.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/components/CheckBoxListDirective.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.velocity.components;
+package org.apache.struts2.views.velocity.components;
 
-import org.apache.struts.action2.components.CheckboxList;
-import org.apache.struts.action2.components.Component;
+import org.apache.struts2.components.CheckboxList;
+import org.apache.struts2.components.Component;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/components/ComboBoxDirective.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/components/ComboBoxDirective.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/components/ComboBoxDirective.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/components/ComboBoxDirective.java Sat Jul  1 16:36:50 2006
@@ -15,10 +15,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.velocity.components;
+package org.apache.struts2.views.velocity.components;
 
-import org.apache.struts.action2.components.ComboBox;
-import org.apache.struts.action2.components.Component;
+import org.apache.struts2.components.ComboBox;
+import org.apache.struts2.components.Component;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
 import javax.servlet.http.HttpServletRequest;
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/iterator/SubsetIteratorTag.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/iterator/SubsetIteratorTag.java Sat Jul  1 16:36:50 2006
@@ -15,11 +15,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.iterator;
+package org.apache.struts2.views.jsp.iterator;
 
-import org.apache.struts.action2.util.SubsetIteratorFilter;
-import org.apache.struts.action2.util.SubsetIteratorFilter.Decider;
-import org.apache.struts.action2.views.jsp.StrutsBodyTagSupport;
+import org.apache.struts2.util.SubsetIteratorFilter;
+import org.apache.struts2.util.SubsetIteratorFilter.Decider;
+import org.apache.struts2.views.jsp.StrutsBodyTagSupport;
 
 import javax.servlet.jsp.JspException;
 
@@ -32,7 +32,7 @@
  * <b>NOTE: JSP-TAG</b>
  * 
  * <p>A tag that takes an iterator and outputs a subset of it. It delegates to
  * {@link org.apache.struts.action2.util.SubsetIteratorFilter} internally to
  * perform the subset functionality.</p>
  * <!-- END SNIPPET: javadoc -->
  *
@@ -182,7 +182,7 @@
     }
 
     /**
-     * @ww.tagattribute required="false" type="org.apache.struts.action2.util.SubsetIteratorFilter.Decider"
+     * @ww.tagattribute required="false" type="org.apache.struts2.util.SubsetIteratorFilter.Decider"
      * description="Extension to plug-in a decider to determine if that particular entry is to be included in the resulting subset iterator"
      */
     public void setDecider(String decider) {
@@ -32,7 +32,7 @@
  * 
  * <p>A tag that takes an iterator and outputs a subset of it. It delegates to
- * {@link org.apache.struts.action2.util.SubsetIteratorFilter} internally to
+ * {@link org.apache.struts2.util.SubsetIteratorFilter} internally to
  * perform the subset functionality.</p>
  * <!-- END SNIPPET: javadoc -->

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/AbstractClosingTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/AbstractClosingTag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/AbstractRichtexteditorResult.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/AbstractRichtexteditorResult.java Sat Jul  1 16:36:50 2006
@@ -15,7 +15,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.jsp.ui;
+package org.apache.struts2.views.jsp.ui;
 
 import java.io.OutputStream;
 import java.io.StringWriter;
@@ -33,10 +33,10 @@
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 
-import org.apache.struts.action2.components.AbstractRichtexteditorConnector.CreateFolderResult;
-import org.apache.struts.action2.components.AbstractRichtexteditorConnector.FileUploadResult;
-import org.apache.struts.action2.components.AbstractRichtexteditorConnector.Folder;
-import org.apache.struts.action2.components.AbstractRichtexteditorConnector.FoldersAndFiles;
+import org.apache.struts2.components.AbstractRichtexteditorConnector.CreateFolderResult;
+import org.apache.struts2.components.AbstractRichtexteditorConnector.FileUploadResult;
+import org.apache.struts2.components.AbstractRichtexteditorConnector.Folder;
+import org.apache.struts2.components.AbstractRichtexteditorConnector.FoldersAndFiles;
 import com.opensymphony.xwork.ActionInvocation;
 import com.opensymphony.xwork.Result;
 
@@ -52,13 +52,13 @@
  * <pre>
  *  &lt;!-- Results necessary when using 'browse server' and 'upload' feature of Richtexteditor --&gt;
  *  &lt;result-type name="richtexteditorGetFolders" 
- *                  class="org.apache.struts.action2.views.jsp.ui.RichtexteditorGetFoldersResult" /&gt;
+ *                  class="org.apache.struts2.views.jsp.ui.RichtexteditorGetFoldersResult" /&gt;
  *  &lt;result-type name="richtexteditorGetFoldersAndFiles" 
- *                  class="org.apache.struts.action2.views.jsp.ui.RichtexteditorGetFoldersAndFilesResult" /&gt;
+ *                  class="org.apache.struts2.views.jsp.ui.RichtexteditorGetFoldersAndFilesResult" /&gt;
  *  &lt;result-type name="richtexteditorCreateFolder" 
- *                  class="org.apache.struts.action2.views.jsp.ui.RichtexteditorCreateFolderResult" /&gt;
+ *                  class="org.apache.struts2.views.jsp.ui.RichtexteditorCreateFolderResult" /&gt;
  *  &lt;result-type name="richtexteditorFileUpload" 
- *                  class="org.apache.struts.action2.views.jsp.ui.RichtexteditorFileUploadResult" /&gt;
+ *                  class="org.apache.struts2.views.jsp.ui.RichtexteditorFileUploadResult" /&gt;
  * </pre>
  * 
  * <!-- END SNIPPET: javadoc -->
@@ -211,7 +211,7 @@
 	 * 
 	 * @param invocation
 	 * @return The server path calculated from AbstractRichtexteditoConnector
-	 * @see org.apache.struts.action2.components.AbstractRichtexteditorConnector#calculateServerPath(String, String, String)
+	 * @see org.apache.struts2.components.AbstractRichtexteditorConnector#calculateServerPath(String, String, String)
 	 */
 	protected String getServerPath(ActionInvocation invocation) {
 		return (String) invocation.getStack().getContext().get("__richtexteditorServerPath");
@@ -224,7 +224,7 @@
 	 * 
 	 * @param invocation
 	 * @return The <code>Folder[]</code> computed from AbstractRichtexteditorConnector
-	 * @see org.apache.struts.action2.components.AbstractRichtexteditorConnector#getFolders(String, String)
+	 * @see org.apache.struts2.components.AbstractRichtexteditorConnector#getFolders(String, String)
 	 */
 	protected Folder[] richtexteditorFolders(ActionInvocation invocation) {
 		return (Folder[]) invocation.getStack().getContext().get("__richtexteditorGetFolders");
@@ -237,7 +237,7 @@
 	 * 
 	 * @param invocation
 	 * @return The <code>FoldersAndFiles</code> computed from AbstractRichtexteditorConnector
-	 * @see org.apache.struts.action2.components.AbstractRichtexteditorConnector#getFoldersAndFiles(String, String)
+	 * @see org.apache.struts2.components.AbstractRichtexteditorConnector#getFoldersAndFiles(String, String)
 	 */
 	protected FoldersAndFiles richtexteditorFoldersAndFiles(ActionInvocation invocation) {
 		return (FoldersAndFiles) invocation.getStack().getContext().get("__richtexteditorGetFoldersAndFiles");
@@ -251,7 +251,7 @@
 	 * 
 	 * @param invocation
 	 * @return The <code>CreateFolderResult</code> computed from AbstractRichtexteditorConnector
-	 * @see org.apache.struts.action2.components.AbstractRichtexteditorConnector#createFolder(String, String, String)
+	 * @see org.apache.struts2.components.AbstractRichtexteditorConnector#createFolder(String, String, String)
 	 */
 	protected CreateFolderResult richtexteditorCreateFolderResult(ActionInvocation invocation) {
 		return (CreateFolderResult) invocation.getStack().getContext().get("__richtexteditorCreateFolder");
@@ -264,7 +264,7 @@
 	 * 
 	 * @param invocation
 	 * @return The <code>FileUploadResult</code> computed from AbstractRichtexteditorConnector
 	 * @see org.apache.struts.action2.components.AbstractRichtexteditorConnector#fileUpload(String, String, String, String, java.io.File)
 	 */
 	protected FileUploadResult richtexteditorFileUploadResult(ActionInvocation invocation) {
 		return (FileUploadResult) invocation.getStack().getContext().get("__richtexteditorFileUpload");
@@ -264,7 +264,7 @@
 	 * @param invocation
 	 * @return The <code>FileUploadResult</code> computed from AbstractRichtexteditorConnector
-	 * @see org.apache.struts.action2.components.AbstractRichtexteditorConnector#fileUpload(String, String, String, String, java.io.File)
+	 * @see org.apache.struts2.components.AbstractRichtexteditorConnector#fileUpload(String, String, String, String, java.io.File)
 	 */
 	protected FileUploadResult richtexteditorFileUploadResult(ActionInvocation invocation) {

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/AbstractUITag.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/jsp/ui/AbstractUITag.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/StrutsVelocityServlet.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/StrutsVelocityServlet.java Sat Jul  1 16:36:50 2006
@@ -15,13 +15,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.velocity;
+package org.apache.struts2.views.velocity;
 
-import org.apache.struts.action2.RequestUtils;
-import org.apache.struts.action2.ServletActionContext;
-import org.apache.struts.action2.StrutsConstants;
-import org.apache.struts.action2.config.Configuration;
-import org.apache.struts.action2.views.util.ContextUtil;
+import org.apache.struts2.RequestUtils;
+import org.apache.struts2.ServletActionContext;
+import org.apache.struts2.StrutsConstants;
+import org.apache.struts2.config.Configuration;
+import org.apache.struts2.views.util.ContextUtil;
 import com.opensymphony.xwork.ActionContext;
 import org.apache.velocity.Template;
 import org.apache.velocity.context.Context;
@@ -45,7 +45,7 @@
 
 
 /**
  * @deprecated please use {@link org.apache.struts.action2.dispatcher.VelocityResult} instead of direct access
  */
 public class StrutsVelocityServlet extends VelocityServlet {
     private VelocityManager velocityManager;
@@ -45,7 +45,7 @@
 
 /**
- * @deprecated please use {@link org.apache.struts.action2.dispatcher.VelocityResult} instead of direct access
+ * @deprecated please use {@link org.apache.struts2.dispatcher.VelocityResult} instead of direct access
  */
 public class StrutsVelocityServlet extends VelocityServlet {

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/VelocityManager.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/VelocityManager.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================
--- struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/VelocityManager.java (original)
+++ struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/VelocityManager.java Sat Jul  1 16:36:50 2006
@@ -15,15 +15,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.struts.action2.views.velocity;
+package org.apache.struts2.views.velocity;
 
-import org.apache.struts.action2.ServletActionContext;
-import org.apache.struts.action2.StrutsConstants;
-import org.apache.struts.action2.config.Configuration;
-import org.apache.struts.action2.util.VelocityStrutsUtil;
-import org.apache.struts.action2.views.jsp.ui.OgnlTool;
-import org.apache.struts.action2.views.util.ContextUtil;
-import org.apache.struts.action2.views.velocity.components.*;
+import org.apache.struts2.ServletActionContext;
+import org.apache.struts2.StrutsConstants;
+import org.apache.struts2.config.Configuration;
+import org.apache.struts2.util.VelocityStrutsUtil;
+import org.apache.struts2.views.jsp.ui.OgnlTool;
+import org.apache.struts2.views.util.ContextUtil;
+import org.apache.struts2.views.velocity.components.*;
 
 import com.opensymphony.xwork.ObjectFactory;
 import com.opensymphony.xwork.util.OgnlValueStack;
@@ -131,7 +131,7 @@
      * <li><strong>res</strong> - the current HttpServletResponse</li>
      * <li><strong>stack</strong> - the current {@link OgnlValueStack}</li>
      * <li><strong>ognl</strong> - an {@link OgnlTool}</li>
      * <li><strong>struts</strong> - an instance of {@link org.apache.struts.action2.util.StrutsUtil}</li>
      * <li><strong>action</strong> - the current Struts action</li>
      * </ul>
      *
@@ -416,7 +416,7 @@
      *  resource.loader = file, class
      *  file.resource.loader.path = real path of webapp
      *  class.resource.loader.description = Velocity Classpath Resource Loader
-     *  class.resource.loader.class = org.apache.struts.action2.views.velocity.StrutsResourceLoader
+     *  class.resource.loader.class = org.apache.struts2.views.velocity.StrutsResourceLoader
      * </pre>
      * <p/>
      * this default configuration can be overridden by specifying a struts.velocity.configfile property in the
@@ -512,7 +512,7 @@
          * Matt Ho - Mon Mar 17 00:21:46 PST 2003
          */
         p.setProperty("safclass.resource.loader.description", "Velocity Classpath Resource Loader");
-        p.setProperty("safclass.resource.loader.class", "org.apache.struts.action2.views.velocity.StrutsResourceLoader");
+        p.setProperty("safclass.resource.loader.class", "org.apache.struts2.views.velocity.StrutsResourceLoader");
         p.setProperty("safclass.resource.loader.modificationCheckInterval", "2");
         p.setProperty("safclass.resource.loader.cache", "true");
 
@@ -131,7 +131,7 @@
      * <li><strong>stack</strong> - the current {@link OgnlValueStack}</li>
      * <li><strong>ognl</strong> - an {@link OgnlTool}</li>
-     * <li><strong>struts</strong> - an instance of {@link org.apache.struts.action2.util.StrutsUtil}</li>
+     * <li><strong>struts</strong> - an instance of {@link org.apache.struts2.util.StrutsUtil}</li>
      * <li><strong>action</strong> - the current Struts action</li>
      * </ul>

Modified: struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/components/AbstractDirective.java
URL: http://svn.apache.org/viewvc/struts/struts2/trunk/core/src/main/java/org/apache/struts2/views/velocity/components/AbstractDirective.java?rev=418521&r1=418519&r2=418521&view=diff
==============================================================================